@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Test::PodSpelling; # git description: v2.007000-11-g87c4ddf
-# vim: set ts=8 sts=4 sw=4 tw=115 et :
+package Dist::Zilla::Plugin::Test::PodSpelling; # git description: v2.007005-9-g6b55d07
+# vim: set ts=8 sts=2 sw=2 tw=115 et :
 # ABSTRACT: Author tests for POD spelling
 # KEYWORDS: plugin test spelling words stopwords typos errors documentation
 
-our $VERSION = '2.007001';
+our $VERSION = '2.007006';
 
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
@@ -34,14 +34,14 @@ has wordlist => (
 has spell_cmd => (
     is      => 'ro',
     isa     => 'Str',
-    default => '',                           # default to original
+    default => '',
 );
 
 has stopwords => (
     is      => 'ro',
     isa     => 'ArrayRef[Str]',
     traits  => [ 'Array' ],
-    default => sub { [] },                   # default to original
+    default => sub { [] },
     handles => {
         push_stopwords => 'push',
         uniq_stopwords => 'uniq',
@@ -53,7 +53,7 @@ has directories => (
     isa     => 'ArrayRef[Str]',
     traits  => [ 'Array' ],
     is      => 'ro',
-    default => sub { [] },                   # default to original
+    default => sub { [ qw(bin lib) ] },
     handles => {
         no_directories => 'is_empty',
         print_directories => [ join => ' ' ],
@@ -128,11 +128,11 @@ sub munge_files {
 sub munge_file {
     my ($self, $file) = @_;
 
-    my ($set_spell_cmd, $add_stopwords, $stopwords);
-    if ($self->spell_cmd) {
-        $set_spell_cmd = sprintf "set_spell_cmd('%s');", $self->spell_cmd;
-    }
+    my $set_spell_cmd = $self->spell_cmd
+        ? sprintf("set_spell_cmd('%s');", $self->spell_cmd)
+        : undef;
 
+    # TODO - move this into an attribute builder
     foreach my $holder ( split( /\s/xms, join( ' ',
             @{ $self->zilla->authors },
             $self->zilla->copyright_holder,
@@ -152,10 +152,9 @@ sub munge_file {
         }
     }
 
-    unless ( $self->no_stopwords ) {
-        $add_stopwords = 'add_stopwords(<DATA>);';
-        $stopwords = join "\n", '__DATA__', $self->uniq_stopwords;
-    }
+    my $stopwords = $self->no_stopwords
+        ? undef
+        : join("\n", '__DATA__', sort $self->uniq_stopwords);
 
     $file->content(
         $self->fill_in_string(
@@ -165,7 +164,6 @@ sub munge_file {
                 version       => __PACKAGE__->VERSION,
                 wordlist      => \$self->wordlist,
                 set_spell_cmd => \$set_spell_cmd,
-                add_stopwords => \$add_stopwords,
                 stopwords     => \$stopwords,
                 directories   => \$self->print_directories,
             }
@@ -182,7 +180,7 @@ sub register_prereqs {
             type  => 'requires',
             phase => 'develop',
         },
-        'Test::Spelling' => '0.12',
+        'Test::Spelling' => '0.17',
     );
     return;
 }
@@ -252,7 +250,7 @@ no Moose;
 #pod
 #pod =attr stopwords
 #pod
-#pod If stopwords is set then C<add_stopwords( E<lt>DATAE<gt> )> is added
+#pod If stopwords is set then C<< add_stopwords( <DATA> ) >> is added
 #pod to the test file and the words are added after the C<__DATA__>
 #pod section.
 #pod
@@ -276,7 +274,7 @@ Dist::Zilla::Plugin::Test::PodSpelling - Author tests for POD spelling
 
 =head1 VERSION
 
-version 2.007001
+version 2.007006
 
 =head1 SYNOPSIS
 
@@ -331,7 +329,7 @@ Defaults to nothing.
 
 =head2 stopwords
 
-If stopwords is set then C<add_stopwords( E<lt>DATAE<gt> )> is added
+If stopwords is set then C<< add_stopwords( <DATA> ) >> is added
 to the test file and the words are added after the C<__DATA__>
 section.
 
@@ -364,7 +362,7 @@ L<http://dzil.org/#mailing-list>.
 There is also an irc channel available for users of this distribution, at
 L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+I am also usually active on irc, as 'ether' at C<irc.perl.org> and C<irc.libera.chat>.
 
 =head1 AUTHORS
 
@@ -382,7 +380,7 @@ Marcel Gruenauer <hanekomu@gmail.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Randy Stauner Graham Knop David Golden Harley Pig Alexandr Ciornii Breno G. de Oliveira
+=for stopwords Karen Etheridge Randy Stauner Graham Knop David Golden Alexandr Ciornii Breno G. de Oliveira Harley Pig
 
 =over 4
 
@@ -404,16 +402,16 @@ David Golden <dagolden@cpan.org>
 
 =item *
 
-Harley Pig <harleypig@gmail.com>
-
-=item *
-
 Alexandr Ciornii <alexchorny@gmail.com>
 
 =item *
 
 Breno G. de Oliveira <garu@cpan.org>
 
+=item *
+
+Harley Pig <harleypig@gmail.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENCE
@@ -433,10 +431,10 @@ use warnings;
 use Test::More;
 
 # generated by {{ $name }} {{ $version }}
-use Test::Spelling 0.12;
+use Test::Spelling 0.17;
 use {{ $wordlist }};
 
 {{ $set_spell_cmd }}
-{{ $add_stopwords }}
-all_pod_files_spelling_ok( qw( bin lib {{ $directories }} ) );
+{{ $stopwords ? 'add_stopwords(<DATA>);' : undef }}
+all_pod_files_spelling_ok( qw( {{ $directories }} ) );
 {{ $stopwords }}
